<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <location filename="../src/alert.cpp" line="236"/>
        <source>Close (%1)</source>
        <translation>Chiudi (%1)</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="177"/>
        <source>Collapse</source>
        <translation>Riduci</translation>
    </message>
    <message>
        <location filename="../src/alert.cpp" line="181"/>
        <source>Expand</source>
        <translation>Espandi</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <location filename="../src/alert_layer.cpp" line="37"/>
        <source>Dismiss Alert</source>
        <translation>Chiudi avviso</translation>
    </message>
    <message>
        <location filename="../src/alert_layer.cpp" line="38"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="503"/>
        <source>%1% of %Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="505"/>
        <source>%1% of %Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="507"/>
        <source>%Ln word(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress.cpp" line="509"/>
        <source>%Ln minute(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress.cpp" line="511"/>
        <source>0%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="146"/>
        <source>Daily Progress</source>
        <translation>Progresso giornaliero</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="282"/>
        <source>Longest streak</source>
        <translation>Sequenza più lunga</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="285"/>
        <source>Current streak</source>
        <translation>Sequenza corrente</translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="298"/>
        <source>N/A</source>
        <translation>n.d.</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/daily_progress_dialog.cpp" line="303"/>
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/daily_progress_dialog.cpp" line="304"/>
        <source>%1 &amp;ndash; %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <location filename="../src/daily_progress_label.cpp" line="30"/>
        <location filename="../src/daily_progress_label.cpp" line="47"/>
        <source>%1% of daily goal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <location filename="../src/spelling/dictionary_dialog.cpp" line="36"/>
        <source>Set Language</source>
        <translation>Scegli lingua</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <location filename="../src/document.cpp" line="425"/>
        <source>(Untitled %1)</source>
        <translation type="unfinished">(Senza nome %1)</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="428"/>
        <source>%1 (Read-Only)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <location filename="../src/document.cpp" line="559"/>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="492"/>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Impossibile salvare &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="507"/>
        <source>Save File As</source>
        <translation>Salva con nome</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="517"/>
        <location filename="../src/document.cpp" line="553"/>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Impossibile sovrascrivere &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="546"/>
        <source>Rename File</source>
        <translation>Rinomina File</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="559"/>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Impossibile rinominare &apos;%1&apos;.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="585"/>
        <source>Reload File?</source>
        <translation>Ricarica File?</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="586"/>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="587"/>
        <source>All unsaved changes will be lost.</source>
        <translation>Tutte le modifiche non salvate verranno perse.</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="589"/>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1321"/>
        <source>Untitled %1</source>
        <translation>Senza titolo %1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1375"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="1376"/>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Salvando come testo semplice la formattazione verrà persa. Eliminare la formattazione?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <location filename="../src/document_watcher.cpp" line="191"/>
        <source>File Changed</source>
        <translation>File modificato</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="192"/>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>Il file %1 è stato modificato da un altro programma.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="193"/>
        <source>Do you want to reload the file?</source>
        <translation>Vuoi ricaricare il file?</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="195"/>
        <source>Reload</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="200"/>
        <source>Ignore</source>
        <translation>Ignora</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="211"/>
        <source>File Deleted</source>
        <translation>File eliminato</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="212"/>
        <source>The file %1 was deleted by another program.</source>
        <translation>Il file %1 è stato modificato da un altro programma.</translation>
    </message>
    <message>
        <location filename="../src/document_watcher.cpp" line="213"/>
        <source>Do you want to save or close the file?</source>
        <translation>Vuoi salvare o chiudere il file?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <location filename="../src/fileformats/docx_reader.cpp" line="94"/>
        <source>Unable to open archive.</source>
        <translation>Impossibile aprire l&apos;archivio</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <location filename="../src/find_dialog.cpp" line="47"/>
        <source>Search for:</source>
        <translation>Cerca:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="49"/>
        <source>Replace with:</source>
        <translation>Sostituire con:</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="53"/>
        <source>Ignore case</source>
        <translation>Ignora maiuscole/minuscole</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="54"/>
        <source>Whole words only</source>
        <translation>Solo parole intere</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="55"/>
        <source>Regular expressions</source>
        <translation>Espressioni regolari</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="58"/>
        <source>Search up</source>
        <translation>Cerca su</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="59"/>
        <source>Search down</source>
        <translation>Cerca giù</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="66"/>
        <source>&amp;Find</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="70"/>
        <source>&amp;Replace</source>
        <translation>&amp;Sostituisci</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="74"/>
        <source>Replace &amp;All</source>
        <translation>Sostitusci &amp;tutto</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="151"/>
        <source>Find</source>
        <translation>Trova</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="159"/>
        <source>Replace</source>
        <translation>Sostituisci</translation>
    </message>
    <message numerus="yes">
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Sostituire %n istanze?</numerusform>
            <numerusform>Sostituire %n istanze?</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="275"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <location filename="../src/find_dialog.cpp" line="279"/>
        <location filename="../src/find_dialog.cpp" line="354"/>
        <source>Phrase not found.</source>
        <translation>Frase non trovata.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="71"/>
        <source>OpenDocument Text</source>
        <translation>OpenDocument (*.odt)</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="73"/>
        <source>Office Open XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="75"/>
        <source>Rich Text Format</source>
        <translation>Rich Text (*. rtf)</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="77"/>
        <source>Plain Text</source>
        <translation>Testo semplice (*.txt)</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="92"/>
        <source>All Files</source>
        <translation>Tutti i files</translation>
    </message>
    <message>
        <location filename="../src/fileformats/format_manager.cpp" line="106"/>
        <source>All Supported Files</source>
        <translation>Formati supportati</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="54"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="55"/>
        <source>Check Spelling...</source>
        <translation>Controllo ortografico...</translation>
    </message>
    <message>
        <location filename="../src/spelling/highlighter.cpp" line="129"/>
        <source>(No suggestions found)</source>
        <translation>(Nessun suggerimento trovato)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Open Image</source>
        <translation>Apri immagine</translation>
    </message>
    <message>
        <location filename="../src/image_button.cpp" line="100"/>
        <source>Images(%1)</source>
        <translation>Immagini (%1)</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <location filename="../src/locale_dialog.cpp" line="51"/>
        <source>Select application language:</source>
        <translation>Selezionare una lingua per l&apos;applicazione:</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="54"/>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Lingua di sistema&gt;</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <location filename="../src/locale_dialog.cpp" line="189"/>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Per modificare la lingua riavviare l&apos;applicazione.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <location filename="../src/fileformats/odt_reader.cpp" line="68"/>
        <source>Unable to open archive.</source>
        <translation>Impossibile aprire l&apos;archivio.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="109"/>
        <source>Preferences</source>
        <translation>Preferenze</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="112"/>
        <source>General</source>
        <translation>Generale</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="114"/>
        <source>Statistics</source>
        <translation>Statistiche</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="116"/>
        <source>Toolbar</source>
        <translation>Toolbar</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="115"/>
        <source>Spell Checking</source>
        <translation>Controllo ortografico</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="453"/>
        <source>Select Dictionary</source>
        <translation>Selezionare Dizionario</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="467"/>
        <source>Unable to open archive.</source>
        <translation>Impossibile aprire archivio.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="570"/>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>L&apos;archivio non contiene un dizionario utilizzabile.</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="256"/>
        <location filename="../src/preferences_dialog.cpp" line="395"/>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="117"/>
        <source>Shortcuts</source>
        <translation>Scorciatioie</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="257"/>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>C&apos;è un conflitto di scorciatoie. Continuare?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="558"/>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>Il dizionario &quot;%1&quot; esiste già. Vuoi sostituirlo?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="113"/>
        <source>Daily Goal</source>
        <translation>Obiettivo giornaliero</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="793"/>
        <source>None</source>
        <translation>Nessuno</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="795"/>
        <source>Minutes:</source>
        <translation>Minuti:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="802"/>
        <location filename="../src/preferences_dialog.cpp" line="912"/>
        <source>Words:</source>
        <translation>Parole:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="705"/>
        <source>Editing</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="707"/>
        <source>Always vertically center</source>
        <translation>Sempre centrato in verticale</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="708"/>
        <source>Block insertion cursor</source>
        <translation>Blocca inserimento del cursore</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="709"/>
        <source>Smooth fonts</source>
        <translation>Font &quot;morbide&quot;</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="710"/>
        <source>Typewriter sounds</source>
        <translation>Suoni della macchina da scrivere</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="712"/>
        <source>Smart quotes:</source>
        <translation>Virgolette:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="719"/>
        <source>Double</source>
        <translation>Doppie</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="720"/>
        <source>Single</source>
        <translation>Singole</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="741"/>
        <source>Scenes</source>
        <translation>Scene</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="748"/>
        <source>Divider:</source>
        <translation>Divisore</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="751"/>
        <source>Saving</source>
        <translation>Salvataggio</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="753"/>
        <source>Automatically save changes</source>
        <translation>Salva automaticamente le modifiche</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="754"/>
        <source>Remember cursor position</source>
        <translation>Ricorda la posizione del cursore</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="872"/>
        <source>Word count</source>
        <translation>Conteggio parole</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="873"/>
        <source>Page count</source>
        <translation>Conteggio pagine</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="874"/>
        <source>Paragraph count</source>
        <translation>Conteggio paragrafi</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="875"/>
        <source>Character count</source>
        <translation>Conteggio caratteri</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="898"/>
        <source>Characters:</source>
        <translation>Caratteri:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="905"/>
        <source>Paragraphs:</source>
        <translation>Paragrafi:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="884"/>
        <source>Word Count Algorithm</source>
        <translation>Algoritmo di conteggio parole</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="396"/>
        <source>Reset daily progress for today to zero?</source>
        <translation>Resettare a zero i progressi quotidiani?</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="755"/>
        <source>Write byte order mark in plain text files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="757"/>
        <source>Default format:</source>
        <translation>Formato preimpostato:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="818"/>
        <source>Reset Today</source>
        <translation>Azzera Oggi</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="831"/>
        <source>History</source>
        <translation>Cronologia</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="833"/>
        <source>Remember history</source>
        <translation>Ricorda cronologia</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="836"/>
        <source>Show streaks</source>
        <translation>Mostra sequenze</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="851"/>
        <source>Minimum progress for streaks:</source>
        <translation>Minimo progresso per sequenza:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="886"/>
        <source>Detect word boundaries</source>
        <translation>Rileva limiti delle parole</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="887"/>
        <source>Divide character count by six</source>
        <translation>Dividere per sei il conteggio caratteri</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="888"/>
        <source>Count each letter as a word</source>
        <translation>Computa ciascuna lettera come parola</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="896"/>
        <source>Page Count Algorithm</source>
        <translation>Algoritmo di conteggio pagine</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1039"/>
        <source>Style</source>
        <translation>Stile</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1042"/>
        <source>Icons Only</source>
        <translation>Solo icone</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1043"/>
        <source>Text Only</source>
        <translation>Solo testo</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1044"/>
        <source>Text Alongside Icons</source>
        <translation>Testo e icone allineate</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1045"/>
        <source>Text Under Icons</source>
        <translation>Testo sotto le icone</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1049"/>
        <source>Text Position:</source>
        <translation>Posizione testo:</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1052"/>
        <source>Actions</source>
        <translation>Azioni</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1068"/>
        <source>Move Up</source>
        <translation>Sposta su</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1070"/>
        <source>Move Down</source>
        <translation>Sposta giù</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1072"/>
        <source>Add Separator</source>
        <translation>Aggiungi separatore</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Shortcut</source>
        <translation>Scorciatoia</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1106"/>
        <source>Action</source>
        <translation>Azione</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="959"/>
        <source>Check spelling as you type</source>
        <translation>Controllo ortografico durante la digitazione</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="960"/>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignora parole MAIUSCOLE</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="961"/>
        <source>Ignore words with numbers</source>
        <translation>Ignora parole con numeri</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="974"/>
        <source>Language</source>
        <translation>Lingua</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="978"/>
        <location filename="../src/preferences_dialog.cpp" line="999"/>
        <source>Add</source>
        <translation>Aggiungi</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1011"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="994"/>
        <source>Personal Dictionary</source>
        <translation>Dizionario personale</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <location filename="../src/fileformats/rtf_reader.cpp" line="209"/>
        <location filename="../src/fileformats/rtf_reader.cpp" line="213"/>
        <source>Not a supported RTF file.</source>
        <translation>Non è un file RTF valido.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <location filename="../src/fileformats/rtf_tokenizer.cpp" line="151"/>
        <source>Unexpectedly reached end of file.</source>
        <translation>Fine del file raggiunta inaspettatamente.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <location filename="../src/scene_list.cpp" line="89"/>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Giù</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="94"/>
        <source>Move Scenes Up</source>
        <translation>Sposta scene su</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="95"/>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Su</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="115"/>
        <source>Toggle Scene List</source>
        <translation>Attiva lista scene</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="116"/>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="399"/>
        <source>Show scene list (%1)</source>
        <translation>Visualizza lista scene (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="400"/>
        <source>Hide scene list (%1)</source>
        <translation>Nascondi lista scene (%1)</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="147"/>
        <source>Filter</source>
        <translation>Filtro</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="88"/>
        <source>Move Scenes Down</source>
        <translation>Sposta scene giù</translation>
    </message>
    <message>
        <location filename="../src/scene_list.cpp" line="155"/>
        <source>Resize scene list</source>
        <translation>Ridimensiona lista scene</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <location filename="../src/session.cpp" line="43"/>
        <location filename="../src/session_manager.cpp" line="57"/>
        <location filename="../src/session_manager.cpp" line="428"/>
        <location filename="../src/session_manager.cpp" line="451"/>
        <location filename="../src/session_manager.cpp" line="460"/>
        <location filename="../src/session_manager.cpp" line="461"/>
        <source>Default</source>
        <translation>Default</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <location filename="../src/session_manager.cpp" line="52"/>
        <source>Manage Sessions</source>
        <translation>Gestione sessioni</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="83"/>
        <source>S&amp;essions</source>
        <translation>S&amp;essioni</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="97"/>
        <source>New</source>
        <translation>Nuova</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="100"/>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="103"/>
        <source>Rename</source>
        <translation>Rinomina</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="106"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="109"/>
        <source>Switch To</source>
        <translation>Passa a</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="220"/>
        <source>New Session</source>
        <translation>Nuova sessione</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="279"/>
        <source>Duplicate Session</source>
        <translation>Duplica sessione</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="324"/>
        <source>Rename Session</source>
        <translation>Rinomina sessione</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="351"/>
        <source>Delete selected session?</source>
        <translation>Eliminare sessione selezionata?</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="423"/>
        <source>Session name:</source>
        <translation>Nome sessione:</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>Sorry</source>
        <translation>Spiacente</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="431"/>
        <source>The requested session name is already in use.</source>
        <translation>Il nome di sessione richiesto è già in uso.</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>&amp;New...</source>
        <translation>&amp;New...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="487"/>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl + Maiusc + N</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>&amp;Manage...</source>
        <translation>&amp;Gestione...</translation>
    </message>
    <message>
        <location filename="../src/session_manager.cpp" line="488"/>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl + Maiusc + M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="126"/>
        <source>Clear</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/shortcut_edit.cpp" line="129"/>
        <source>Reset to Default</source>
        <translation>Ripristina default</translation>
    </message>
    <message>
        <location filename="../src/preferences_dialog.cpp" line="1149"/>
        <location filename="../src/symbols_dialog.cpp" line="219"/>
        <source>Shortcut:</source>
        <translation>Scorciatoia:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <location filename="../src/smart_quotes.cpp" line="150"/>
        <source>Replacing quotation marks...</source>
        <translation>Sostituzione virgolette ...</translation>
    </message>
    <message>
        <location filename="../src/smart_quotes.cpp" line="151"/>
        <source>Please Wait</source>
        <translation>Attendere prego</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="134"/>
        <source>Check Spelling</source>
        <translation>Controllo ortografico</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="142"/>
        <source>&amp;Add</source>
        <translation>&amp;Aggiungi</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="145"/>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignora</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="148"/>
        <source>I&amp;gnore All</source>
        <translation>Ignora &amp;tutto</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="153"/>
        <source>&amp;Change</source>
        <translation>&amp;Cambia</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="156"/>
        <source>C&amp;hange All</source>
        <translation>Cambia t&amp;utto</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="171"/>
        <source>Not in dictionary:</source>
        <translation>Non nel dizionario:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="179"/>
        <source>Change to:</source>
        <translation>Cambia in:</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Checking spelling...</source>
        <translation>Controllo ortografico...</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="195"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="196"/>
        <source>Please wait</source>
        <translation>Attendere prego</translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="223"/>
        <source>Continue checking at beginning of file?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/spelling/spell_checker.cpp" line="282"/>
        <source>Spell check complete.</source>
        <translation>Controllo ortografico completato.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="96"/>
        <source>Symbols</source>
        <translation>Simboli</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="103"/>
        <source>Recently used symbols</source>
        <translation>Simboli usati recentemente</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="133"/>
        <source>All symbols</source>
        <translation>Tutti i simboli</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="195"/>
        <source>Details</source>
        <translation>Dettagli</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="221"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../src/symbols_dialog.cpp" line="231"/>
        <source>Insert</source>
        <translation>Inserisci</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Blocks</source>
        <translation>Blocchi</translation>
    </message>
    <message>
        <location filename="../src/symbols_model.cpp" line="107"/>
        <source>Scripts</source>
        <translation>Script</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <location filename="../src/theme.cpp" line="103"/>
        <source>Untitled %1</source>
        <translation>Senza titolo %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <location filename="../src/theme_dialog.cpp" line="103"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>No Image</source>
        <translation>Nessuna Immagine</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Tiled</source>
        <translation>Piastrellato</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Centered</source>
        <translation>Centrato</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Stretched</source>
        <translation>Stirato</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Scaled</source>
        <translation>Scalato</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="164"/>
        <source>Zoomed</source>
        <translation>Zoommato</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="211"/>
        <source>Opacity:</source>
        <translation>Opacità:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="212"/>
        <source>Position:</source>
        <translation>Posizione:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="213"/>
        <source>Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="217"/>
        <source>Round Text Background Corners</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="231"/>
        <location filename="../src/theme_dialog.cpp" line="249"/>
        <location filename="../src/theme_dialog.cpp" line="279"/>
        <source>Radius:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="235"/>
        <source>Blur Text Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="253"/>
        <source>Text Background Drop Shadow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="280"/>
        <source>Vertical Offset:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="284"/>
        <source>Margins</source>
        <translation>Margini</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="302"/>
        <source>Window:</source>
        <translation>Finestra:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="303"/>
        <source>Page:</source>
        <translation>Pagina:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="361"/>
        <source>Indent first line</source>
        <translation>Indenta prima linea</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="368"/>
        <source>Above:</source>
        <translation>Sopra:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="369"/>
        <source>Below:</source>
        <translation>Sotto:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="160"/>
        <source>Remove</source>
        <translation>Rimuovi</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="93"/>
        <source>Edit Theme</source>
        <translation>Modifica tema</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="150"/>
        <source>Window Background</source>
        <translation>Sfondo della finestra</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="178"/>
        <location filename="../src/theme_dialog.cpp" line="332"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="144"/>
        <location filename="../src/theme_dialog.cpp" line="176"/>
        <location filename="../src/theme_dialog.cpp" line="210"/>
        <location filename="../src/theme_dialog.cpp" line="278"/>
        <source>Color:</source>
        <translation>Colore:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="177"/>
        <source>Image:</source>
        <translation>Immagine:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="202"/>
        <location filename="../src/theme_dialog.cpp" line="224"/>
        <location filename="../src/theme_dialog.cpp" line="242"/>
        <location filename="../src/theme_dialog.cpp" line="264"/>
        <location filename="../src/theme_dialog.cpp" line="271"/>
        <location filename="../src/theme_dialog.cpp" line="288"/>
        <location filename="../src/theme_dialog.cpp" line="295"/>
        <location filename="../src/theme_dialog.cpp" line="344"/>
        <location filename="../src/theme_dialog.cpp" line="350"/>
        <location filename="../src/theme_dialog.cpp" line="356"/>
        <source> pixels</source>
        <translation> pixel</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Left</source>
        <translation>Sinistra</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="182"/>
        <source>Text Background</source>
        <translation>Sfondo del testo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="196"/>
        <source>Right</source>
        <translation>Destra</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="116"/>
        <source>Text</source>
        <translation>Testo</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="145"/>
        <source>Font:</source>
        <translation>Tipo di carattere:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="146"/>
        <source>Misspelled:</source>
        <translation>Errori di ortografia:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="307"/>
        <source>Line Spacing</source>
        <translation>Interlinea</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Single</source>
        <translation>Singola</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>1.5 Lines</source>
        <translation>1.5 linee</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Double</source>
        <translation>Doppia</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="311"/>
        <source>Proportional</source>
        <translation>Proporzionale</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="333"/>
        <source>Height:</source>
        <translation>Altezza:</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="341"/>
        <source>Paragraph Spacing</source>
        <translation>Spaziatura paragrafi</translation>
    </message>
    <message>
        <location filename="../src/theme_dialog.cpp" line="367"/>
        <source>Tab Width:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="253"/>
        <source>New Theme</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <location filename="../src/theme_manager.cpp" line="78"/>
        <source>Themes</source>
        <translation>Temi</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="92"/>
        <source>Default</source>
        <translation type="unfinished">Default</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="107"/>
        <source>Gentle Blues</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="108"/>
        <source>Old School</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="109"/>
        <source>Space Dreams</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="110"/>
        <source>Writing Desk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="113"/>
        <location filename="../src/theme_manager.cpp" line="174"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="117"/>
        <location filename="../src/theme_manager.cpp" line="178"/>
        <source>Duplicate</source>
        <translation>Duplica</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="131"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="183"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="188"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="193"/>
        <source>Import</source>
        <translation>Importa</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="197"/>
        <source>Export</source>
        <translation>Export</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="311"/>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Themes (%1)</source>
        <translation>Temi</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="339"/>
        <source>Import Theme</source>
        <translation>Importa Tema</translation>
    </message>
    <message>
        <location filename="../src/theme_manager.cpp" line="416"/>
        <source>Export Theme</source>
        <translation>Esporta Tema</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <location filename="../src/timer.cpp" line="255"/>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="340"/>
        <source>Delete timer?</source>
        <translation>Cancella timer?</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="355"/>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Parole&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="356"/>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Pagine&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="357"/>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Paragrafi&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="358"/>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caratteri&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="402"/>
        <source>Set Delay</source>
        <translation>Imposta ritardo</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="403"/>
        <source>Set Time</source>
        <translation>Imposta tempo</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="406"/>
        <source>Delay:</source>
        <translation>Ritardo:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="409"/>
        <source>Time:</source>
        <translation>Tempo:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="418"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="431"/>
        <source>Alarm</source>
        <translation>Allarme</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="444"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="448"/>
        <source>Memo:</source>
        <translation>Memo:</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="459"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../src/timer.cpp" line="461"/>
        <source>Delete</source>
        <translation>Elimina</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <location filename="../src/timer_display.cpp" line="150"/>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_display.cpp" line="160"/>
        <source>No timers running</source>
        <translation>Nessun timer in esecuzione</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <location filename="../src/timer_manager.cpp" line="46"/>
        <source>Timers</source>
        <translation>Timer</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="78"/>
        <source>New</source>
        <translation>Nuovo</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="83"/>
        <source>Recent</source>
        <translation>Recenti</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Question</source>
        <translation>Domanda</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="123"/>
        <source>Cancel editing timers?</source>
        <translation>Annulla modifica timer?</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="316"/>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <location filename="../src/timer_manager.cpp" line="323"/>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <location filename="../src/window.cpp" line="300"/>
        <source>Loading themes</source>
        <translation>Caricamento temi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1146"/>
        <source>Loading sounds</source>
        <translation>Caricamento suoni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="309"/>
        <location filename="../src/window.cpp" line="1065"/>
        <source>Untitled</source>
        <translation>Senza nome</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="682"/>
        <source>Open File</source>
        <translation>Apri file</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="864"/>
        <source>About FocusWriter</source>
        <translation>A proposito di FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="867"/>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="868"/>
        <source>A simple fullscreen word processor</source>
        <translation>Un semplice editor di testo a pieno schermo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="869"/>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="870"/>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Rilasciato sotto licenza &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="871"/>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Utilizza icone del tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="872"/>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Sotto licenza &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="174"/>
        <location filename="../src/window.cpp" line="928"/>
        <source>Characters: %L1 / %L2</source>
        <translation>Caratteri:%L1 / %L2</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="172"/>
        <location filename="../src/window.cpp" line="929"/>
        <source>Pages: %L1</source>
        <translation>Pagine: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="173"/>
        <location filename="../src/window.cpp" line="930"/>
        <source>Paragraphs: %L1</source>
        <translation>Paragrafi: %L1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="171"/>
        <location filename="../src/window.cpp" line="931"/>
        <source>Words: %L1</source>
        <translation>Parole: %L1</translation>
    </message>
    <message>
        <location filename="../src/document.cpp" line="602"/>
        <location filename="../src/window.cpp" line="1020"/>
        <source>Opening %1</source>
        <translation>Apertura %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="332"/>
        <source>(Untitled %1)</source>
        <translation>(Senza nome %1)</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="207"/>
        <source>List all documents</source>
        <translation>Lista tutti i documenti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="210"/>
        <source>Switch to Next Document</source>
        <translation>Passa al documento successivo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="216"/>
        <source>Switch to Previous Document</source>
        <translation>Passa al documento precedente</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="222"/>
        <source>Switch to First Document</source>
        <translation>Passa al primo documento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="228"/>
        <source>Switch to Last Document</source>
        <translation>Passa all&apos;ultimo documento</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="236"/>
        <source>Switch to Document %1</source>
        <translation>Passa al documento %1</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="296"/>
        <source>Loading settings</source>
        <translation>Caricamento impostazioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="318"/>
        <source>Emergency cache is not writable.</source>
        <translation>La cache di emergenza non è scrivibile</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="338"/>
        <location filename="../src/window.cpp" line="1034"/>
        <source>Warning</source>
        <translation>Attenzione</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="339"/>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>FocusWriter non è stato chiuso correttamente.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="340"/>
        <source>Restore from the emergency cache?</source>
        <translation>Ripristinare dalla cache di emergenza?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="467"/>
        <source>Some files could not be opened.</source>
        <translation>Non è stato possibile aprire alcuni file.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="470"/>
        <source>Some files were opened Read-Only.</source>
        <translation>Alcuni file sono stati aperti in sola lettura.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1035"/>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&apos;%1&apos; è più recente della copia in cache.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1036"/>
        <source>Overwrite newer file?</source>
        <translation>Sovrascrivere il file più recente?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1121"/>
        <source>Save Changes?</source>
        <translation>Salvare le modifiche?</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1122"/>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1123"/>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>Le tue modifiche andranno perse se non le salvi.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1153"/>
        <source>Unable to load typewriter sounds.</source>
        <translation>Impossibile caricare i suoni della macchina per scrivere.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1154"/>
        <source>Please make sure that SDL_mixer is installed.</source>
        <translation>Accertati che SDL_mixer sia installato.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1290"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1291"/>
        <source>&amp;New</source>
        <translation>&amp;Nuovo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1292"/>
        <source>&amp;Open...</source>
        <translation>&amp;Apri...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1293"/>
        <source>Reloa&amp;d</source>
        <translation>Ricarica</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1295"/>
        <source>&amp;Save</source>
        <translation>&amp;Salva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1297"/>
        <source>Save &amp;As...</source>
        <translation>Salva &amp;con nome...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1298"/>
        <source>&amp;Rename...</source>
        <translation>&amp;Rinomina...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1300"/>
        <source>Save A&amp;ll</source>
        <translation>Salva</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1303"/>
        <source>Manage Sessions</source>
        <translation>Gestione sessioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1305"/>
        <source>New Session</source>
        <translation>Nuova sessione</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1308"/>
        <source>&amp;Print...</source>
        <translation>&amp;Stampa...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1310"/>
        <source>&amp;Close</source>
        <translation>&amp;Chiudi</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1311"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl + Q</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1315"/>
        <source>&amp;Edit</source>
        <translation>&amp;Modifica</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1316"/>
        <source>&amp;Undo</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1319"/>
        <source>&amp;Redo</source>
        <translation>&amp;Ripeti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1323"/>
        <source>Cu&amp;t</source>
        <translation>Ta&amp;glia</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1326"/>
        <source>&amp;Copy</source>
        <translation>&amp;Copia</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1329"/>
        <source>&amp;Paste</source>
        <translation>&amp;Incolla</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Paste &amp;Unformatted</source>
        <translation>Incolla &amp;non formattato</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1330"/>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1332"/>
        <source>Select &amp;All</source>
        <translation>Seleziona &amp;tutto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Select &amp;Scene</source>
        <translation>Seleziona &amp;scena</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1333"/>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1336"/>
        <source>Fo&amp;rmat</source>
        <translation>For&amp;matta</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1338"/>
        <source>&amp;Bold</source>
        <translation>&amp;Grassetto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1340"/>
        <source>&amp;Italic</source>
        <translation>&amp;Corsivo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1342"/>
        <source>&amp;Underline</source>
        <translation>&amp;Sottolineato</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Stri&amp;kethrough</source>
        <translation>Bar&amp;rato</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1344"/>
        <source>Ctrl+K</source>
        <translation>Ctrl + K</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Sup&amp;erscript</source>
        <translation>Ap&amp;ice</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1346"/>
        <source>Ctrl+^</source>
        <translation>Ctrl + ^</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>&amp;Subscript</source>
        <translation>&amp;Pedice</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1348"/>
        <source>Ctrl+_</source>
        <translation>Ctrl + _</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Align &amp;Left</source>
        <translation>Allinea &amp;Sinistra</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1352"/>
        <source>Ctrl+{</source>
        <translation>Ctrl + {</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Align &amp;Center</source>
        <translation>Allinea &amp;Cenro</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1354"/>
        <source>Ctrl+|</source>
        <translation>Ctrl + |</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Align &amp;Right</source>
        <translation>Allinea &amp;Right</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1356"/>
        <source>Ctrl+}</source>
        <translation>Ctrl + }</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Align &amp;Justify</source>
        <translation>Allineare &amp;p;Giustificato</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1358"/>
        <source>Ctrl+J</source>
        <translation>Ctrl + J</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>&amp;Decrease Indent</source>
        <translation>&amp; Riduci rientro</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1368"/>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl + &lt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>I&amp;ncrease Indent</source>
        <translation>A&amp;umentare rientro</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1369"/>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl + &gt;</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1372"/>
        <source>Le&amp;ft to Right Block</source>
        <translation>Blocco da sinistra a destra</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1374"/>
        <source>Ri&amp;ght to Left Block</source>
        <translation>Blocco da destra a sinistra</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1382"/>
        <source>&amp;Tools</source>
        <translation>&amp;Strumenti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1383"/>
        <source>&amp;Find...</source>
        <translation>&amp;Trova...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1384"/>
        <source>Find &amp;Next</source>
        <translation>Trova &amp;successivo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1387"/>
        <source>Find Pre&amp;vious</source>
        <translation>Trova Pre&amp;cedente</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>&amp;Replace...</source>
        <translation>&amp;Sostituisci...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1390"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1392"/>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Citazioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1393"/>
        <source>Update &amp;Document</source>
        <translation>Aggiorna &amp;document</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1396"/>
        <source>Update &amp;Selection</source>
        <translation>Aggiorna &amp;selezione</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>&amp;Spelling...</source>
        <translation>&amp;Ortografia...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1400"/>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1401"/>
        <source>Set &amp;Language...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1403"/>
        <source>&amp;Timers...</source>
        <translation>&amp;Timer...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1404"/>
        <source>S&amp;ymbols...</source>
        <translation>S&amp;imboli</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1405"/>
        <source>&amp;Daily Progress</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1408"/>
        <source>&amp;Settings</source>
        <translation>&amp;Impostazioni</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1409"/>
        <source>Show &amp;Toolbar</source>
        <translation>Mostra &amp;barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1414"/>
        <source>Show &amp;Menu Icons</source>
        <translation>Mostra &amp;icone del menu</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1420"/>
        <source>F&amp;ocused Text</source>
        <translation>Testo a fuoco</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Schermo intero</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1422"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1424"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimizza</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1428"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1430"/>
        <source>&amp;Themes...</source>
        <translation>&amp;Temi...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1433"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferenze...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1439"/>
        <source>Focus Off</source>
        <translation>Messa a fuoco disattivata</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1441"/>
        <source>Focus One Line</source>
        <translation>Metti a fuoco una linea</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1443"/>
        <source>Focus Three Lines</source>
        <translation>Metti a fuoco tre linee</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1444"/>
        <source>&amp;Paragraph</source>
        <translation>&amp;Paragrafo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1445"/>
        <source>Focus Paragraph</source>
        <translation>Paragrafo a fuoco</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1454"/>
        <source>Ctrl+Shift+`</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1459"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1432"/>
        <source>Application &amp;Language...</source>
        <translation>Lingua &amp;applicazione...</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="400"/>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Qualche file non è supportato e non è stato aperto.</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1438"/>
        <source>&amp;Off</source>
        <translation>Non attivo</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1440"/>
        <source>One &amp;Line</source>
        <translation>Una &amp;Linea</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1442"/>
        <source>&amp;Three Lines</source>
        <translation>&amp;Tre Linee</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1460"/>
        <source>&amp;About</source>
        <translation>&amp;Informazioni su</translation>
    </message>
    <message>
        <location filename="../src/window.cpp" line="1468"/>
        <source>About &amp;Qt</source>
        <translation>Informazioni su &amp;Qt</translation>
    </message>
</context>
</TS>
